@@ -5,3 +5,5 @@ __email__ = "jr@aphyt.com"
 
 from .cip import *
 from .cip_datatypes import *
+from .cip_attributes import *
+from .cip_services import *
