@@ -4,6 +4,7 @@ __maintainer__ = "Joseph Ryan"
 __email__ = "jr@aphyt.com"
 
 from abc import ABC, abstractmethod
+import aphyt.cip as ap
 import binascii
 
 
@@ -20,23 +21,6 @@ def cip_crc16(data: bytes, poly=0xa001) -> bytes:
     return crc.to_bytes(2, 'little')
 
 
-class CIPService:
-    """
-    ToDo make each service an object that inherits from CIPService
-    """
-    READ_TAG_SERVICE = b'\x4c'
-    READ_TAG_FRAGMENTED_SERVICE = b'\x52'
-    WRITE_TAG_SERVICE = b'\x4d'
-    WRITE_TAG_FRAGMENTED_SERVICE = b'\x53'
-    READ_MODIFY_WRITE_TAG_SERVICE = b'\x4e'
-    # w506_nx_nj - series_cpu_unit_built - in_ethernet_ip_port_users_manual_en.pdf
-    # 303 of 570 CIP Object Services
-    GET_ATTRIBUTE_ALL = b'\x01'
-    GET_ATTRIBUTE_SINGLE = b'\x0e'
-    RESET = b'\x05'
-    SET_ATTRIBUTE_SINGLE = b'\x10'
-
-
 class CIPRequest:
     """
     Class for assembling CIP requests
@@ -137,6 +121,8 @@ class CIPDispatcher(ABC):
 
     The key method that subclasses need to implement is 'execute_cip_command' which will
     send a CIPRequest over the CIP network and receive a CIPReply
+
+    ToDo monitor when the read, write, get, set services have all moved to CIP objects mixins and get rid of them
     """
 
     def __init__(self):
@@ -151,7 +137,7 @@ class CIPDispatcher(ABC):
 
     def read_tag_service(self, tag_request_path, number_of_elements=1) -> CIPReply:
         read_tag_request = \
-            CIPRequest(CIPService.READ_TAG_SERVICE, tag_request_path, number_of_elements.to_bytes(2, 'little'))
+            CIPRequest(ap.CIPService.READ_TAG_SERVICE, tag_request_path, number_of_elements.to_bytes(2, 'little'))
         return self.execute_cip_command(read_tag_request)
 
     def write_tag_service(self, tag_request_path, request_service_data: CIPCommonFormat, number_of_elements=1):
@@ -159,22 +145,34 @@ class CIPDispatcher(ABC):
                int(request_service_data.additional_info_length).to_bytes(1, 'little') + \
                request_service_data.additional_info + number_of_elements.to_bytes(2, 'little') + \
                request_service_data.data
-        write_tag_request = CIPRequest(CIPService.WRITE_TAG_SERVICE, tag_request_path, data)
+        write_tag_request = CIPRequest(ap.CIPService.WRITE_TAG_SERVICE, tag_request_path, data)
         return self.execute_cip_command(write_tag_request)
 
     def read_tag_fragmented_service(self, tag_request_path, offset, number_of_elements):
         data = tag_request_path + number_of_elements.to_bytes(2, 'little') + offset.to_bytes(4, 'little')
         read_tag_fragmented_request = \
-            CIPRequest(CIPService.READ_TAG_FRAGMENTED_SERVICE, tag_request_path, data)
+            CIPRequest(ap.CIPService.READ_TAG_FRAGMENTED_SERVICE, tag_request_path, data)
         return self.execute_cip_command(read_tag_fragmented_request)
 
     def write_tag_fragmented_service(self, tag_request_path, cip_datatype_code, data, offset, number_of_elements=1):
         data = \
             cip_datatype_code + b'\x00' + number_of_elements.to_bytes(2, 'little') + \
             offset.to_bytes(4, 'little') + data
-        write_tag_fragmented_request = CIPRequest(CIPService.WRITE_TAG_FRAGMENTED_SERVICE, tag_request_path, data)
+        write_tag_fragmented_request = CIPRequest(ap.CIPService.WRITE_TAG_FRAGMENTED_SERVICE, tag_request_path, data)
         return self.execute_cip_command(write_tag_fragmented_request)
 
+    def get_attribute_all_service(self, tag_request_path):
+        get_attribute_all_request = CIPRequest(ap.CIPService.GET_ATTRIBUTE_ALL, tag_request_path)
+        return self.execute_cip_command(get_attribute_all_request)
+
+    def get_attribute_single_service(self, tag_request_path):
+        get_attribute_single_request = CIPRequest(ap.CIPService.GET_ATTRIBUTE_SINGLE, tag_request_path)
+        return self.execute_cip_command(get_attribute_single_request)
+
+    def set_attribute_single_service(self, tag_request_path):
+        set_attribute_single_request = CIPRequest(ap.CIPService.SET_ATTRIBUTE_SINGLE, tag_request_path)
+        return self.execute_cip_command(set_attribute_single_request)
+
 
 def address_request_path_segment(class_id: bytes = None, instance_id: bytes = None,
                                  attribute_id: bytes = None, element_id: bytes = None) -> bytes:
